/*
 * Copyright (C) 2017  Kevin Whitaker <eyecreate@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#ifndef GROOVEPLAYER_H
#define GROOVEPLAYER_H

#include <Wt/Dbo/Session>
#include <Wt/Dbo/backend/Sqlite3>
#include <vector>
#include <thread>
#include "db/User.h"
#include "db/AudioTrack.h"

class GroovePlayer
{
public:
    static GroovePlayer* getInstance() {
        static GroovePlayer instance("music.db");
        return &instance;
    };
    GroovePlayer(GroovePlayer const&) = delete;
    void operator=(GroovePlayer const&) = delete;
private:
    GroovePlayer(std::string dbFile);
    Wt::Dbo::backend::Sqlite3 sqliteConnection;
    Wt::Dbo::Session sqlSession;
    
    std::vector<AudioTrack*> requestQueue;
    std::thread* grooveEvents;
    static void grooveEventLoop();
    std::vector<AudioTrack*> getNextVoteBatch();
    std::thread* grooveAudioScanner;
    static void grooveAudioScannerLoop();
    
};

#endif // GROOVEPLAYER_H
